@@ -1,9 +1,13 @@
 package Animal;
 use Rubyish::Attribute qw(:all);
 
-attr_accessor qw(name);
-attr_reader qw(color);
-attr_writer qw(type);
+BEGIN {
+
+  attr_accessor qw(name);
+  attr_reader qw(color);
+  attr_writer qw(type);
+
+}
 
 sub new {
     my ($class, $args) = @_;
@@ -16,18 +20,18 @@ sub new {
 
 sub instant_name {
   my ($self, $new_name) = @_;
-  __name__() = $new_name;
-  __name__();
+  __name__ = $new_name;
+  __name__;
 }
 
 sub instant_color {
   my ($self) = @_;
-  __color__();
+  __color__;
 }
 
 sub instant_type {
   my ($self) = @_;
-  __type__();
+  __type__;
 }
 
 
